Documentation
¶
Index ¶
- Constants
- func NewAdminClient(ctx context.Context, client *http.Client, adminAddressPath string) (internalapi.AdminClient, error)
- func NewAdminClientForURL(baseURL string, client *http.Client) (internalapi.AdminClient, error)
- func PollEnvoyPidAndAdminAddressPath(ctx context.Context, funcEPid int, runID string) (envoyPid int, adminAddressPath string, err error)
Constants ¶
const ( ServerAddr = "127.0.0.1:9901" AddressPathFlag = "--admin-address-path" )
Variables ¶
This section is empty.
Functions ¶
func NewAdminClient ¶
func NewAdminClient(ctx context.Context, client *http.Client, adminAddressPath string) (internalapi.AdminClient, error)
NewAdminClient creates an AdminClient by polling for the admin port at adminAddressPath.
func NewAdminClientForURL ¶ added in v1.5.0
func NewAdminClientForURL(baseURL string, client *http.Client) (internalapi.AdminClient, error)
NewAdminClientForURL creates an AdminClient for the given base URL and HTTP client factory.
func PollEnvoyPidAndAdminAddressPath ¶
func PollEnvoyPidAndAdminAddressPath(ctx context.Context, funcEPid int, runID string) (envoyPid int, adminAddressPath string, err error)
PollEnvoyPidAndAdminAddressPath polls for a child process tagged with runID and extracts its pid and admin address path from its command line.
This polls because the child may not exist yet when the caller starts.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.